@@ -1,5 +1,5 @@
 
 IS_ARTICLE_TYPE_ENABLED = False
 IS_ARTICLE_HITCOUNT_ENABLED = False
-IS_ARTICLE_COMMENTS_ENABLED = False
-IS_ARTICLE_TAGS_ENABLED = False
+ARE_COMMENTS_ENABLED = False
+ARE_TAGS_ENABLED = False
